Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJohn Arthorne2004-06-18 17:52:08 +0000
committerJohn Arthorne2004-06-18 17:52:08 +0000
commitc92779a4b7eb3b0848a36a913dbdb20fe811efde (patch)
tree61baba88a3c9ea50a8502457df44cc373b7eead0
parent5e7567681628bae6bf848d44fd3de6a0eaa57caf (diff)
downloadeclipse.platform.runtime-c92779a4b7eb3b0848a36a913dbdb20fe811efde.tar.gz
eclipse.platform.runtime-c92779a4b7eb3b0848a36a913dbdb20fe811efde.tar.xz
eclipse.platform.runtime-c92779a4b7eb3b0848a36a913dbdb20fe811efde.zip
Bug 67855 javadoc for IStatus out of datev20040618a
-rw-r--r--bundles/org.eclipse.core.runtime/src/org/eclipse/core/runtime/IStatus.java7
-rw-r--r--bundles/org.eclipse.core.runtime/src/org/eclipse/core/runtime/Status.java12
2 files changed, 12 insertions, 7 deletions
diff --git a/bundles/org.eclipse.core.runtime/src/org/eclipse/core/runtime/IStatus.java b/bundles/org.eclipse.core.runtime/src/org/eclipse/core/runtime/IStatus.java
index da9c14d9c..5c5330252 100644
--- a/bundles/org.eclipse.core.runtime/src/org/eclipse/core/runtime/IStatus.java
+++ b/bundles/org.eclipse.core.runtime/src/org/eclipse/core/runtime/IStatus.java
@@ -67,6 +67,7 @@ public interface IStatus {
* cancelation
* @see #getSeverity()
* @see #matches(int)
+ * @since 3.0
*/
public static final int CANCEL = 0x08;
@@ -116,6 +117,7 @@ public interface IStatus {
* Returns the severity. The severities are as follows (in
* descending order):
* <ul>
+ * <li><code>CANCEL</code> - cancelation occurred</li>
* <li><code>ERROR</code> - a serious error (most severe)</li>
* <li><code>WARNING</code> - a warning (less severe)</li>
* <li><code>INFO</code> - an informational ("fyi") message (least severe)</li>
@@ -127,8 +129,8 @@ public interface IStatus {
* no children.
* </p>
*
- * @return the severity: one of <code>OK</code>,
- * <code>ERROR</code>, <code>INFO</code>, or <code>WARNING</code>
+ * @return the severity: one of <code>OK</code>, <code>ERROR</code>,
+ * <code>INFO</code>, <code>WARNING</code>, or <code>CANCEL</code>
* @see #matches(int)
*/
public int getSeverity();
@@ -171,6 +173,7 @@ public interface IStatus {
* @return <code>true</code> if there is at least one match,
* <code>false</code> if there are no matches
* @see #getSeverity()
+ * @see #CANCEL
* @see #ERROR
* @see #WARNING
* @see #INFO
diff --git a/bundles/org.eclipse.core.runtime/src/org/eclipse/core/runtime/Status.java b/bundles/org.eclipse.core.runtime/src/org/eclipse/core/runtime/Status.java
index 9b11e8e9c..54b1ab6f7 100644
--- a/bundles/org.eclipse.core.runtime/src/org/eclipse/core/runtime/Status.java
+++ b/bundles/org.eclipse.core.runtime/src/org/eclipse/core/runtime/Status.java
@@ -33,8 +33,8 @@ public class Status implements IStatus {
/**
* The severity. One of
* <ul>
- * <li><code>ERROR</code></li>
* <li><code>CANCEL</code></li>
+ * <li><code>ERROR</code></li>
* <li><code>WARNING</code></li>
* <li><code>INFO</code></li>
* <li>or <code>OK</code> (0)</li>
@@ -65,8 +65,8 @@ public class Status implements IStatus {
/**
* Creates a new status object. The created status has no children.
*
* @param severity the severity; one of <code>OK</code>,
* <code>ERROR</code>, <code>INFO</code>, or <code>WARNING</code>
* @param pluginId the unique identifier of the relevant plug-in
* @param code the plug-in-specific status code, or <code>OK</code>
* @param message a human-readable message, localized to the
@@ -188,8 +188,8 @@ public class Status implements IStatus {
/**
* Sets the severity.
*
* @param severity the severity; one of <code>OK</code>,
* <code>ERROR</code>, <code>INFO</code>, or <code>WARNING</code>
*/
protected void setSeverity(int severity) {
Assert.isLegal(severity == OK || severity == ERROR || severity == WARNING || severity == INFO || severity == CANCEL);
@@ -211,6 +211,8 @@ public class Status implements IStatus {
buf.append("WARNING"); //$NON-NLS-1$
} else if (severity == INFO) {
buf.append("INFO"); //$NON-NLS-1$
+ } else if (severity == CANCEL) {
+ buf.append("CANCEL"); //$NON-NLS-1$
} else {
buf.append("severity="); //$NON-NLS-1$
buf.append(severity);
@@ -65,8 +65,8 @@ public class Status implements IStatus {
* Creates a new status object. The created status has no children.
*
- * @param severity the severity; one of <code>OK</code>,
- * <code>ERROR</code>, <code>INFO</code>, or <code>WARNING</code>
+ * @param severity the severity; one of <code>OK</code>, <code>ERROR</code>,
+ * <code>INFO</code>, <code>WARNING</code>, or <code>CANCEL</code>
* @param pluginId the unique identifier of the relevant plug-in
* @param code the plug-in-specific status code, or <code>OK</code>
@@ -188,8 +188,8 @@ public class Status implements IStatus {
* Sets the severity.
*
- * @param severity the severity; one of <code>OK</code>,
- * <code>ERROR</code>, <code>INFO</code>, or <code>WARNING</code>
+ * @param severity the severity; one of <code>OK</code>, <code>ERROR</code>,
+ * <code>INFO</code>, <code>WARNING</code>, or <code>CANCEL</code>
*/
protected void setSeverity(int severity) {

Back to the top